Reports | OiRA

Topics

# Reports

You can use a report to:

- provide evidence to supervisory authorities;
- pass information to the people concerned (workers, safety representatives, employers, experts in occupational safety and health, etc.);
- monitor and assess whether necessary measures have been introduced;
- record any revisions if circumstances change (new machines/workers, or as a result of the findings of any accident investigations, etc.).

You can save the report on your computer and print it. You can also modify it or add more information. Please note that any changes made in a report that you have downloaded will NOT be saved in the OiRA tool.

## Report choices

There are different kinds of reports available for different purposes. The selection of reports available for the specific tools depends on decisions taken by the national OiRA partner/tool developer.

The available reports.

### Full report

Format: Word / Office Open XML (.docx). Can be edited by you after download.

Provides: all the information and input entered by you throughout the risk assessment process.

Use it to: provide evidence of the risk assessment for supervisory authorities (e.g. the labour inspectorate).

### Action plan

Format: Excel / Office Open XML (.xlsx). Can be edited by you after download

Provides: information on all the measures you have chosen to implement.

Use it to:

- actively follow up on the implementation of measures that you have chosen;
- manage the problems/risks in your workplace (specific tasks, expertise, responsibilities, deadlines).

### Risks overview

Format: Portable Document Format (.pdf). Cannot be edited by you after download.

Provides: an overview of the risks identified

Use it to:

- get a quick overview of the status of risks in your workplace;
- pass information to the people concerned;
- monitor whether risks/measures are properly dealt with.

### Measures overview

Format: Portable Document Format (.pdf). Cannot be edited by you after download.

Provides: a quick overview of the measures to be implemented.

Use it to:

- get a quick overview of the status of measures you have decided to implement;
- pass information to the people concerned;
- monitor whether risks/measures are properly dealt with.

Scroll to top Load toolbar…
Back

## 4-reports.md

More…

- New risk assessment
- Show archived risk assessments
- All types of risk assessments Only regular risk assessments Only contractor risk assessments

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More